@@ -1,6 +1,7 @@
+from enum import StrEnum
 from uuid import UUID
 
-from sqlalchemy import Column, JSON
+from sqlalchemy import Column, JSON, Enum
 from sqlmodel import Field
 
 from ..general.models import BaseModel
@@ -14,10 +15,19 @@ class IntegrationsOrganizationModel(IntegrationsModel):
     organization: UUID = Field(index=True)
 
 
+class IntegrationType(StrEnum):
+    ATS = 'ats'
+    SOCIAL = 'social'
+    JOB_BOARD = 'job-board'
+    COMMUNICATION = 'communication'
+    DATA = 'data'
+    OTHER = 'other'
+
+
 class Integration(IntegrationsModel, table=True):
     name: str = Field(index=True)
     icon: str = Field(index=True)
-    type: str = Field(index=True)
+    type: IntegrationType = Field(sa_column=Column(Enum(IntegrationType)))
     tag: str = Field(index=True, nullable=True)
     enabled: bool = Field(default=True, nullable=True)
     description: str = Field(index=True, nullable=True)
